@@ -4,7 +4,7 @@
  *
  * This program is free software; you can redistribute it and/or modify it
  * under the terms of the GNU General Public License as published by the
- * Free Software Foundation; either version 2 of the License, or (at your
+ * Free Software Foundation; either version 3 of the License, or (at your
  * option) any later version.
  *
  * This program is distributed in the hope that it will be useful, but
@@ -56,7 +56,7 @@ compare_iters (GtkTreeModel *model,
   gtk_tree_model_get (model, iter_a, BLOCK_CHAPTERS_MODEL_LABEL, &label_a, -1);
   gtk_tree_model_get (model, iter_b, BLOCK_CHAPTERS_MODEL_LABEL, &label_b, -1);
 
-  ret = strcmp (label_a, label_b);
+  ret = g_utf8_collate (label_a, label_b);
 
   g_free (label_a);
   g_free (label_b);
@@ -103,9 +103,6 @@ gucharmap_block_chapters_model_init (GucharmapBlockChaptersModel *model)
                                    GUCHARMAP_CHAPTERS_MODEL_COLUMN_LABEL,
                                    (GtkTreeIterCompareFunc) compare_iters,
                                    NULL, NULL);
-  gtk_tree_sortable_set_sort_column_id (GTK_TREE_SORTABLE (model),
-                                        GUCHARMAP_CHAPTERS_MODEL_COLUMN_LABEL,
-                                        GTK_SORT_ASCENDING);
 }
 
 static GucharmapCodepointList *
